#
# spec file for package ghc-aeson
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name aeson
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        1.1.2.0
Release:        lp150.1.8
Summary:        Fast JSON parsing and encoding
License:        BSD-3-Clause
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/1.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-attoparsec-devel
BuildRequires:  ghc-base-compat-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-dlist-devel
BuildRequires:  ghc-hashable-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-scientific-devel
BuildRequires:  ghc-tagged-devel
BuildRequires:  ghc-template-haskell-devel
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-time-locale-compat-devel
BuildRequires:  ghc-unordered-containers-devel
BuildRequires:  ghc-uuid-types-devel
BuildRequires:  ghc-vector-devel
%if %{with tests}
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-base-orphans-devel
BuildRequires:  ghc-base16-bytestring-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-generic-deriving-devel
BuildRequires:  ghc-hashable-time-devel
BuildRequires:  ghc-integer-logarithms-devel
BuildRequires:  ghc-quickcheck-instances-devel
BuildRequires:  ghc-test-framework-devel
BuildRequires:  ghc-test-framework-hunit-devel
BuildRequires:  ghc-test-framework-quickcheck2-devel
%endif

%description
A JSON parsing and encoding library optimized for ease of use and high
performance.

To get started, see the documentation for the 'Data.Aeson' module below.

Parsing performance on a late 2013 MacBook Pro (2.6GHz Core i7), running 64-bit
GHC 7.10.1, for mostly-English tweets from Twitter's JSON search API:

* 6.4 KB payloads, English: 7570 msg/sec (47.6 MB/sec)

* 14.6 KB payloads, Japanese: 3261 msg/sec (46.6 MB/sec)

Encoding performance on the same machine and data:

* 6.4 KB payloads, English: 22738 msg/sec (142.9 MB/sec)

* 14.6 KB payloads, Japanese: 15911 msg/sec (227.4 MB/sec)

(A note on naming: in Greek mythology, Aeson was the father of Jason.).

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%doc LICENSE

%files devel -f %{name}-devel.files
%doc README.markdown changelog.md examples

%changelog
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Thu Jul 27 2017 psimons@suse.com
- Update to version 1.1.2.0 revision 1.
* Tue Apr  4 2017 psimons@suse.com
- Update to version 1.0.2.1 revision 1 with cabal2obs.
* Sun Feb 12 2017 psimons@suse.com
- Update to version 1.0.2.1 with cabal2obs.
* Thu Jan 26 2017 psimons@suse.com
- Update to version 0.11.3.0 with cabal2obs.
* Mon Sep 19 2016 psimons@suse.com
- Update to version 0.11.2.1 revision 1 with cabal2obs.
* Wed Aug 17 2016 psimons@suse.com
- Update to version 0.11.2.1 revision 0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.11.2.0 revision 1 with cabal2obs.
* Thu May 26 2016 mimi.vx@gmail.com
- update to 0.11.2.0
  * Enable PolyKinds to generalize Proxy, Tagged, and Const instances.
  * Add unsafeToEncoding in Data.Aeson.Types, use with care!
* Fri Mar 25 2016 mimi.vx@gmail.com
- update to 0.11.1.4
  * Fix build with base < 4.8 and unordered-containers < 0.2.6.
  * Add missing field in docs for defaultOptions.
  * Fixes a bug where the hashes of equal values could differ.
  * The only changes are added instances. (0.11.1.0)
    + These are new:
    ToJSON a => ToJSON (NonEmpty a)
    FromJSON a => FromJSON (NonEmpty a)
    ToJSON (Proxy a)
    FromJSON (Proxy a)
    ToJSON b => ToJSON (Tagged a b)
    FromJSON b => FromJSON (Tagged a b)
    ToJSON a => ToJSON (Const a b)
    FromJSON a => FromJSON (Const a b)
    + These are now available for older GHCs:
    ToJSON Natural
    FromJSON Natural
  * This release should be close to backwards compatible with aeson 0.9 (0.11.0.0)
    + Breaking changes:
    Revert .:? to behave like it did in 0.9. If you want the 0.10 behavior
    use .:! instead.
    Revert JSON format of Either to 0.9, Left and Right are now serialized with
    an initial uppercase letter. If you want the names in lowercase you can
    add a newtype with an instance.
    All ToJSON and FromJSON instances except for [a] are no longer OVERLAPPABLE.
    Mark your instance as OVERLAPPING if it overlaps any of the other aeson
    instances.
    All ToJSON and FromJSON instances except for [Char] are no longer
    incoherent, this means you may need to replace your incoherent instances
    with a newtyped instance.
    + Additions:
    Introduce .:! that behaves like .:? did in 0.10.
    Allow HH:MM format for ZonedTime and UTCTime. This is one of the formats
    allowed by ISO 8601.
    Added ToJSON and FromJSON instances for the Version, Ordering, and Natural
    types.
    + Bug fixes:
    JSONPath identifiers are now escaped if they contain invalid characters.
    Fixed JSONPath messages for Seq to include indices.
    Fixed JSONPath messages for Either to include left/right.
    Fix missing quotes surrounding time encodings.
    Fix #293: Type error in TH when using omitNothingFields = True.
* Mon Sep 28 2015 mimi.vx@gmail.com
- update to 0.9.0.1
  * A stray export of encodeToBuilder got away!
  * The json and json' parsers are now synonyms for value and value', in conformance
  with the looser semantics of RFC 7159.
  * Renamed encodeToByteStringBuilder to the more compact encodeToBuilder.
  * The dependency on the unordered-containers package was too lax, and has been
  corrected.
  * Encoding a Scientific value with a huge exponent is now handled efficiently.
  (This would previously allocate a huge arbitrary-precision integer, potentially
  leading to a denial of service.)
  * Handling of strings that contain backslash escape sequences is greatly improved.
  For a pathological string containing almost a megabyte of consecutive backslashes,
  the new implementation is 27x faster and uses 42x less memory.
  * The ToJSON instance for UTCTime is rendered with higher (picosecond) resolution.
  * The value parser now correctly handles leading whitespace.
  * New instances of ToJSON and FromJSON for Data.Sequence and Data.Functor.Identity.
  The Value type now has a Read instance.
  * ZonedTime parser ordering now favours the standard JSON format, increasing
    efficiency in the common case.
  * Encoding to a Text.Builder now escapes '<' and '>' characters, to reduce XSS risk.
* Wed Apr 22 2015 mimi.vx@gmail.com
- update to 0.8.0.2
  * Fix ToJSON instance for 15-tuples.
  * Support time-1.5.
  * Add ToJSON and FromJSON instances for tuples of up to 15 elements.
  * Major compiler and library compatibility changes: we have dropped
  support for GHC older than 7.4, text older than 1.1, and bytestring
  older than 0.10.4.0.  Supporting the older versions had become
  increasingly difficult, to the point where it was no longer worth
  it.
  * The performance of encoding to and decoding of bytestrings have both
  improved by up to 2x, while also using less memory.
  * New dependency: the scientific package lets us parse floating point
  numbers more quickly and accurately.
  * eitherDecode, decodeStrictWith: fixed bugs.
  * Added FromJSON and ToJSON instances for Tree and Scientific.
  * Fixed the ToJSON instances for UTCTime and ZonedTime.
* Sun Nov  9 2014 peter.trommler@ohm-hochschule.de
- drop aeson-disable-TH.patch
  * Template Haskell (TH) now available on all supprted archs
* Sat Oct 18 2014 dvaleev@suse.com
- disable TH module on arch's without ghci
  aeson-disable-TH.patch
* Mon Oct 28 2013 sbahling@suse.com
- Remove redundant Requires for ghc-compiler
* Mon Oct  7 2013 sbahling@suse.com
- Initial package - version 0.6.2.0
